@@ -16,12 +16,12 @@ log = logging.getLogger("FolderEditor")
 COLOR_NEW				= "#A0A0A0"
 # Regexp to generate folder id from filename
 RE_GEN_ID = re.compile("([a-zA-Z0-9\-\._]{1,64}).*")
-VALUES = [ "vlabel", "vid", "vpath", "vreadOnly", "vignorePerms", "vdevices",
-	"vversioning", "vkeepVersions", "vrescanIntervalS", "vmaxAge",
+VALUES = [ "vlabel", "vid", "vpath", "vreadOnly", "vreceiveOnly", "vignorePerms",
+	"vdevices", "vversioning", "vkeepVersions", "vrescanIntervalS", "vmaxAge",
 	"vversionsPath", "vfsWatcherEnabled", "vcleanoutDays", "vcommand", "vorder",
 	"vminDiskFreePct"
 	]
-VERSIONING_TYPES = set(['simple', 'staggered', 'trashcan', 'external'])
+VERSIONING_TYPES = {'simple', 'staggered', 'trashcan', 'external'}
 
 class FolderEditorDialog(EditorDialog):
 	def __init__(self, app, is_new, id=None, path=None):
@@ -80,6 +80,8 @@ class FolderEditorDialog(EditorDialog):
 			return self.get_burried_value("versioning/params/versionsPath", self.values, "")
 		elif key == "readOnly":
 			return self.get_burried_value("type", self.values, "") in ("readonly", "sendonly")
+		elif key == "receiveOnly":
+			return self.get_burried_value("type", self.values, "") in ("receiveonly")
 		elif key == "versioning":
 			return self.get_burried_value("versioning/type", self.values, "")
 		else:
@@ -111,8 +113,13 @@ class FolderEditorDialog(EditorDialog):
 			# Create structure if needed
 			self.create_dicts(self.values, ("versioning", "params", "versionsPath"))
 			self.values["versioning"]["params"]["versionsPath"] = value
-		elif key == "readOnly":
-			self.values["type"] = "sendonly" if value else "sendreceive"
+		elif key in ("readOnly", "receiveonly"):
+			if self["vreadOnly"].get_active():
+				self.values["type"] = "sendonly"
+			elif self["vreceiveOnly"].get_active():
+				self.values["type"] = "receiveonly"
+			else:
+				self.values["type"] = "sendreceive"
 		else:
 			EditorDialog.set_value(self, key, value)
 	
@@ -153,7 +160,7 @@ class FolderEditorDialog(EditorDialog):
 				}
 				self["vpath"].set_sensitive(False)
 				self["btBrowse"].set_sensitive(False)
-		except KeyError, e:
+		except KeyError as e:
 			# ID not found in configuration. This is practicaly impossible,
 			# so it's handled only by self-closing dialog.
 			log.exception(e)
@@ -170,7 +177,7 @@ class FolderEditorDialog(EditorDialog):
 				if device["id"] != self.app.daemon.get_my_id():
 					b = Gtk.CheckButton(device.get_title(), False)
 					b.set_tooltip_text(device["id"])
-					self["vdevices"].pack_end(b, False, False, 0)
+					self["vdevices"].pack_start(b, False, False, 0)
 					b.set_active(device["id"] in nids)
 			self["vdevices"].show_all()
 		else:
@@ -190,9 +197,8 @@ class FolderEditorDialog(EditorDialog):
 				self["rvversioning"].set_reveal_child(True)
 	
 	#@Overrides
-	def on_save_reuqested(self):
+	def on_save_requested(self):
 		self.store_values(VALUES)
-		print self.values
 		if self.is_new:
 			# Add new dict to configuration (edited dict is already there)
 			self.config["folders"].append(self.values)
@@ -226,6 +232,8 @@ class FolderEditorDialog(EditorDialog):
 					key=lambda x : x.get_title().lower()
 				))
 			box.set_color_hex(COLOR_NEW)
+		else:
+			self.app.daemon.reload_config()
 	
 	#@Overrides
 	def ui_value_changed(self, w, *a):
@@ -256,6 +264,13 @@ class FolderEditorDialog(EditorDialog):
 		self.update_special_widgets()
 		self["vid"].set_sensitive(not readonly)
 	
+	def on_folder_type_toggled(self, cb, *a):
+		""" Ensures that only one folder type checkbox is checked """
+		if cb.get_active():
+			for x in ("vreadOnly", "vreceiveOnly"):
+				if self[x] != cb and self[x].get_active():
+					self[x].set_active(False)
+	
 	def on_vfsWatcherEnabled_toggled(self, cb, *a):
 		# Called when checkbox value changes to automatically change rescan interval
 		if self._loading: return
@@ -269,8 +284,6 @@ class FolderEditorDialog(EditorDialog):
 			# fswatch disabled, return rescan interval back
 			if interval > 300:
 				vrescanIntervalS.set_value(interval / 60)
-				
-		# print self.get_value("vfsWatcherEnabled"),  cb.get_value()
 	
 	def mark_device(self, nid):
 		""" Marks (checks) checkbox for specified device """
