@@ -200,6 +200,10 @@ class Page(Gtk.Grid):
 		""" Sets page as complete by default """
 		self.parent.set_page_complete(self, True)
 
+	def init_page(self):
+		""" Initialize the page """
+		raise NotImplementedError()
+
 class IntroPage(Page):
 	TYPE = Gtk.AssistantPageType.INTRO
 	TITLE = "Intro"
@@ -216,15 +220,19 @@ class IntroPage(Page):
 			# order is 'apply, next, back, finish, cancel'
 			next_label = all_buttons[1].get_label().decode("utf-8").replace("_", "")
 		except: pass
+		# TODO: Temporal solution, remove later
+		changed_line = _("Continue this wizard to create a Syncthing configuration file or abort it to exit.")
+		if "%s" in changed_line:
+			changed_line = changed_line % (next_label,)
+		
 		self.attach(WrappedLabel(
 			"<b>" + _("Welcome to Syncthing-GTK first run wizard!") + "</b>" +
 			"\n\n" +
 			_("It looks like you never have used Syncthing.") + " " +
 			_("Initial configuration should be created.") +  " " +
-			(_("Please click <b>%s</b> to create a Syncthing configuration file or <b>Quit</b> to exit")
-				% (next_label,) ) + "\n\n" +
+			changed_line + "\n\n" +
 			(_("If you already had Syncthing daemon configured, please, "
-			  "exit this wizard and check your %s folder") % config_folder_link )
+			   "exit this wizard and check your %s folder") % config_folder_link )
 		), 0, 0, 1, 1)
 
 class FindDaemonPage(Page):
@@ -249,8 +257,14 @@ class FindDaemonPage(Page):
 		self.attach(self.label, 0, 0, 1, 1)
 	
 	def prepare(self):
-		self.paths = [ "./" ]
-		self.paths += [ os.path.expanduser("~/.local/bin"), self.parent.st_configdir ]
+		default_path, default_binary = os.path.split(
+				self.parent.config.get_default_value("syncthing_binary"))
+		self.paths = []
+		if default_path:
+			self.paths += [ default_path ]
+		self.paths += [ "./" ]
+		self.paths += [ os.path.expanduser("~/.local/bin") ]
+		self.paths += [ self.parent.st_configdir ]
 		if is_portable():
 			self.paths += [ ".\\data" ]
 		if StDownloader is None:
@@ -261,6 +275,8 @@ class FindDaemonPage(Page):
 			if suffix == "x64":
 				# Allow 32bit binary on 64bit
 				self.binaries += ["syncthing.x86"]
+			if default_binary not in self.binaries:
+				self.binaries = [ default_binary ] + self.binaries
 		if IS_WINDOWS:
 			self.paths += [ "c:/Program Files/syncthing",
 				"c:/Program Files (x86)/syncthing",
@@ -509,7 +525,7 @@ class GenerateKeysPage(Page):
 		# Create it, if needed
 		try:
 			os.makedirs(self.parent.st_configdir)
-		except Exception, e:
+		except Exception as e:
 			self.parent.output_line("syncthing-gtk: Failed to create configuration directory")
 			self.parent.output_line("syncthing-gtk: %s" % (str(e),))
 		# Run syncthing -generate
@@ -647,7 +663,7 @@ class SaveSettingsPage(Page):
 			# Remove config.xml that I just created
 			try:
 				os.unlink(self.parent.st_configfile)
-			except Exception, e:
+			except Exception as e:
 				self.parent.output_line("syncthing-gtk: %s" % (str(e),))
 			self.parent.error(self,
 				_("Failed to find unused port for listening."),
@@ -692,9 +708,10 @@ class SaveSettingsPage(Page):
 		xml = None
 		try:
 			# Load XML file
-			config = file(self.parent.st_configfile, "r").read()
+			with open(self.parent.st_configfile, "r") as conf_file:
+				config = conf_file.read()
 			xml = minidom.parseString(config)
-		except Exception, e:
+		except Exception as e:
 			self.parent.output_line("syncthing-gtk: %s" % (traceback.format_exc(),))
 			self.parent.error(self,
 				_("Failed to load Syncthing configuration"),
@@ -724,7 +741,7 @@ class SaveSettingsPage(Page):
 			gui.setAttribute("enabled", "true")
 			gui.setAttribute("tls", "false")
 			au.firstChild.replaceWholeText("0")
-		except Exception, e:
+		except Exception as e:
 			self.parent.output_line("syncthing-gtk: %s" % (traceback.format_exc(),))
 			self.parent.error(self,
 				_("Failed to modify Syncthing configuration"),
@@ -733,8 +750,9 @@ class SaveSettingsPage(Page):
 			return False
 		try:
 			# Write XML back to file
-			file(self.parent.st_configfile, "w").write(xml.toxml().encode("utf-8"))
-		except Exception, e:
+			with open(self.parent.st_configfile, "w") as f:
+				f.write(xml.toxml().encode("utf-8"))
+		except Exception as e:
 			self.parent.output_line("syncthing-gtk: %s" % (traceback.format_exc(),))
 			self.parent.error(self,
 				_("Failed to save Syncthing configuration"),
